@@ -1,34 +1,29 @@
-import base64
-import os
+import shutil
 from io import BytesIO
+from pathlib import Path
 
-import boto3
+import numpy as np
 import pytest
 import requests
+
 from monitaur import Monitaur
 from monitaur.exceptions import ClientAuthError, ClientValidationError
-from monitaur.virgil.alibi.tabular import AnchorTabular
+
+CLIENT_BASE_DIR = Path(__file__).resolve(strict=True).parent.parent.parent
+DATA_BASE_DIR = Path(CLIENT_BASE_DIR).joinpath("_example", "data")
 
 model_data = {
     "name": "Diabetes Classifier",
     "model_type": "random_forest",
     "model_class": "tabular",
-    "library": "scikit_learn",
-    "trained_model_hash": "7fa8962a",
-    "production_file_hash": "ec9b7a68",
+    "library": "scikit-learn",
     "feature_number": 8,
     "owner": "Anthony Habayeb",
     "developer": "Andrew Clark",
-    "influences": True,
+    "influences": "anchors",
 }
 
 record_training_data = {
-    "credentials": {
-        "aws_access_key": "some access key",
-        "aws_secret_key": "some secret key",
-        "aws_region": "us-east-1",
-        "aws_bucket_name": "some bucket name",
-    },
     "model_set_id": 1,
     "feature_names": [
         "Pregnancies",
@@ -43,25 +38,13 @@ record_training_data = {
 }
 
 record_training_image_data = {
-    "credentials": {
-        "aws_access_key": "some access key",
-        "aws_secret_key": "some secret key",
-        "aws_region": "us-east-1",
-        "aws_bucket_name": "some bucket name",
-    },
     "model_set_id": 1,
 }
 
 transaction_data = {
-    "credentials": {
-        "aws_access_key": "some access key",
-        "aws_secret_key": "some secret key",
-        "aws_region": "us-east-1",
-        "aws_bucket_name": "some bucket name",
-    },
     "model_set_id": 1,
-    "trained_model_hash": "7fa8962a",
-    "production_file_hash": "ec9b7a68",
+    "trained_model": Path(DATA_BASE_DIR).joinpath("data.joblib"),
+    "prediction_file": Path(CLIENT_BASE_DIR).joinpath("_example", "prediction.py"),
     "prediction": "",
     "features": {},
     "python_version": "1.1.1",
@@ -118,7 +101,9 @@ def test_record_transaction_returns_response_json_given_success_response(mocker)
     response = requests.Response()
     response.status_code = 200
     mocker.patch.object(
-        response, "json", return_value={"version": 1, "influences": True}
+        response,
+        "json",
+        return_value={"version": 1, "influences": "anchors", "model_class": "tabular"},
     )
     mocker.patch.object(monitaur._session, "get", return_value=response)
     mock_explain_transaction = mocker.patch(
@@ -130,19 +115,87 @@ def test_record_transaction_returns_response_json_given_success_response(mocker)
     mocker.patch.object(response, "json", return_value={"id": 1})
     mocker.patch.object(monitaur._session, "post", return_value=response)
     mocker.patch.object(monitaur, "authenticate", return_value="Token")
+    mock_upload_file_to_s3 = mocker.patch("monitaur.client.upload_file_to_s3",)
 
     transaction_details = monitaur.record_transaction(**transaction_data)
 
     assert transaction_details["id"] is not None
     assert mock_explain_transaction.call_count == 1
+    assert mock_upload_file_to_s3.call_count == 2
 
 
-def test_when_influences_false_record_transaction_skips_explain_transaction(mocker):
+def test_record_transaction_counterfactuals_model_true(mocker):
+    monitaur = Monitaur(client_secret="secret")
+    payload = transaction_data.copy()
+    payload["additional_libraries"] = {"numpy": "2.22.0"}
+    response = requests.Response()
+    response.status_code = 200
+    mocker.patch.object(
+        response,
+        "json",
+        return_value={
+            "version": 1,
+            "influences": "anchors",
+            "counterfactual": True,
+            "model_class": "tabular",
+        },
+    )
+    mocker.patch.object(monitaur._session, "get", return_value=response)
+    mock_explain_transaction = mocker.patch(
+        "monitaur.client.get_influences",
+        return_value=["Glucose <= 99.00", "BMI <= 27.35"],
+    )
+    response = requests.Response()
+    response.status_code = 200
+    mocker.patch.object(response, "json", return_value={"id": 1})
+    mocker.patch.object(monitaur._session, "post", return_value=response)
+    mocker.patch.object(monitaur, "authenticate", return_value="Token")
+    mock_upload_file_to_s3 = mocker.patch("monitaur.client.upload_file_to_s3",)
+
+    transaction_details = monitaur.record_transaction(**payload)
+
+    assert transaction_details["id"] is not None
+    assert mock_explain_transaction.call_count == 1
+    assert mock_upload_file_to_s3.call_count == 2
+
+
+def test_record_transaction_counterfactuals_model_true_no_lib(mocker):
     monitaur = Monitaur(client_secret="secret")
     response = requests.Response()
     response.status_code = 200
     mocker.patch.object(
-        response, "json", return_value={"version": 1, "influences": False}
+        response,
+        "json",
+        return_value={
+            "version": 1,
+            "influences": "anchors",
+            "counterfactual": True,
+            "model_class": "tabular",
+        },
+    )
+    mocker.patch.object(monitaur._session, "get", return_value=response)
+    mocker.patch(
+        "monitaur.client.get_influences",
+        return_value=["Glucose <= 99.00", "BMI <= 27.35"],
+    )
+    response = requests.Response()
+    response.status_code = 200
+    mocker.patch.object(response, "json", return_value={"id": 1})
+    mocker.patch.object(monitaur._session, "post", return_value=response)
+    mocker.patch.object(monitaur, "authenticate", return_value="Token")
+
+    with pytest.raises(ClientValidationError):
+        monitaur.record_transaction(**transaction_data)
+
+
+def test_when_influences_none_record_transaction_skips_explain_transaction(mocker):
+    monitaur = Monitaur(client_secret="secret")
+    response = requests.Response()
+    response.status_code = 200
+    mocker.patch.object(
+        response,
+        "json",
+        return_value={"version": 1, "influences": None, "model_class": "tabular"},
     )
     mocker.patch.object(monitaur._session, "get", return_value=response)
     mock_explain_transaction = mocker.patch("monitaur.client.get_influences")
@@ -151,11 +204,13 @@ def test_when_influences_false_record_transaction_skips_explain_transaction(mock
     mocker.patch.object(response, "json", return_value={"id": 1})
     mocker.patch.object(monitaur._session, "post", return_value=response)
     mocker.patch.object(monitaur, "authenticate", return_value="Token")
+    mock_upload_file_to_s3 = mocker.patch("monitaur.client.upload_file_to_s3",)
 
     transaction_details = monitaur.record_transaction(**transaction_data)
 
     assert transaction_details["id"] is not None
     assert mock_explain_transaction.call_count == 0
+    assert mock_upload_file_to_s3.call_count == 2
 
 
 def test_record_transaction_raises_client_auth_error_given_unauthorized_response(
@@ -181,7 +236,7 @@ def test_record_transaction_on_image_model_raise_client_validation_error_if_no_i
     mocker.patch.object(
         response,
         "json",
-        return_value={"version": 1, "influences": True, "model_class": "image"},
+        return_value={"version": 1, "influences": "grad-cam", "model_class": "image"},
     )
     mocker.patch.object(monitaur._session, "get", return_value=response)
     mocker.patch.object(monitaur, "authenticate", return_value="Token")
@@ -209,10 +264,11 @@ def test_record_transaction_on_image_model_raise_client_validation_error_if_inva
     image_tran_data["image"] = "Invalid Image path"
 
     response.status_code = 200
+
     mocker.patch.object(
         response,
         "json",
-        return_value={"version": 1, "influences": True, "model_class": "image"},
+        return_value={"version": 1, "influences": "grad-cam", "model_class": "image"},
     )
     mocker.patch.object(monitaur._session, "get", return_value=response)
     mocker.patch.object(monitaur, "authenticate", return_value="Token")
@@ -224,11 +280,13 @@ def test_record_transaction_on_image_model_raise_client_validation_error_if_inva
     response.status_code = 400
     mocker.patch.object(response, "json", return_value={"id": 1})
     mocker.patch.object(monitaur._session, "post", return_value=response)
+    mock_upload_file_to_s3 = mocker.patch("monitaur.client.upload_file_to_s3",)
 
     with pytest.raises(ClientValidationError):
         monitaur.record_transaction(**image_tran_data)
 
     assert mock_explain_transaction.call_count == 0
+    assert mock_upload_file_to_s3.call_count == 2
 
 
 def test_record_transaction_on_image_model_raise_client_validation_error_if_image_not_exists(
@@ -240,10 +298,11 @@ def test_record_transaction_on_image_model_raise_client_validation_error_if_imag
     image_tran_data["image"] = "image.png"
 
     response.status_code = 200
+
     mocker.patch.object(
         response,
         "json",
-        return_value={"version": 1, "influences": True, "model_class": "image"},
+        return_value={"version": 1, "influences": "grad-cam", "model_class": "image"},
     )
     mocker.patch.object(monitaur._session, "get", return_value=response)
     mocker.patch.object(monitaur, "authenticate", return_value="Token")
@@ -252,7 +311,8 @@ def test_record_transaction_on_image_model_raise_client_validation_error_if_imag
         return_value=["Glucose <= 99.00", "BMI <= 27.35"],
     )
 
-    mocker.patch.object(os.path, "exists", return_value=False)
+    mocker.patch.object(Path, "exists", return_value=False)
+    mock_upload_file_to_s3 = mocker.patch("monitaur.client.upload_file_to_s3",)
 
     response = requests.Response()
     response.status_code = 200
@@ -263,6 +323,7 @@ def test_record_transaction_on_image_model_raise_client_validation_error_if_imag
         monitaur.record_transaction(**image_tran_data)
 
     assert mock_explain_transaction.call_count == 0
+    assert mock_upload_file_to_s3.call_count == 2
 
 
 def test_record_transaction_on_image_model_raise_client_validation_error_if_invalid_file(
@@ -274,10 +335,11 @@ def test_record_transaction_on_image_model_raise_client_validation_error_if_inva
     image_tran_data["image"] = "image.pdf"
 
     response.status_code = 200
+
     mocker.patch.object(
         response,
         "json",
-        return_value={"version": 1, "influences": True, "model_class": "image"},
+        return_value={"version": 1, "influences": "grad-cam", "model_class": "image"},
     )
     mocker.patch.object(monitaur._session, "get", return_value=response)
     mocker.patch.object(monitaur, "authenticate", return_value="Token")
@@ -286,7 +348,8 @@ def test_record_transaction_on_image_model_raise_client_validation_error_if_inva
         return_value=["Glucose <= 99.00", "BMI <= 27.35"],
     )
 
-    mocker.patch.object(os.path, "exists", return_value=True)
+    mocker.patch.object(Path, "exists", return_value=True)
+    mock_upload_file_to_s3 = mocker.patch("monitaur.client.upload_file_to_s3",)
 
     response = requests.Response()
     response.status_code = 200
@@ -297,6 +360,7 @@ def test_record_transaction_on_image_model_raise_client_validation_error_if_inva
         monitaur.record_transaction(**image_tran_data)
 
     assert mock_explain_transaction.call_count == 0
+    assert mock_upload_file_to_s3.call_count == 2
 
 
 def test_record_transaction_on_image_model_raise_client_validation_error_if_image_greater_1mb(
@@ -308,10 +372,11 @@ def test_record_transaction_on_image_model_raise_client_validation_error_if_imag
     image_tran_data["image"] = "image.png"
 
     response.status_code = 200
+
     mocker.patch.object(
         response,
         "json",
-        return_value={"version": 1, "influences": True, "model_class": "image"},
+        return_value={"version": 1, "influences": "grad-cam", "model_class": "image"},
     )
     mocker.patch.object(monitaur._session, "get", return_value=response)
     mocker.patch.object(monitaur, "authenticate", return_value="Token")
@@ -320,8 +385,10 @@ def test_record_transaction_on_image_model_raise_client_validation_error_if_imag
         return_value=["Glucose <= 99.00", "BMI <= 27.35"],
     )
 
-    mocker.patch.object(os.path, "exists", return_value=True)
-    mocker.patch.object(os.path, "getsize", return_value=2097152)
+    mocker.patch.object(Path, "exists", return_value=True)
+    mock_path_stat = mocker.patch.object(Path, "stat")
+    mock_path_stat.return_value.st_size = 2097152
+    mock_upload_file_to_s3 = mocker.patch("monitaur.client.upload_file_to_s3",)
 
     response = requests.Response()
     response.status_code = 200
@@ -332,6 +399,7 @@ def test_record_transaction_on_image_model_raise_client_validation_error_if_imag
         monitaur.record_transaction(**image_tran_data)
 
     assert mock_explain_transaction.call_count == 0
+    assert mock_upload_file_to_s3.call_count == 2
 
 
 def test_record_transaction_on_image_model_success(mocker):
@@ -341,10 +409,11 @@ def test_record_transaction_on_image_model_success(mocker):
     image_tran_data["image"] = "image.png"
 
     response.status_code = 200
+
     mocker.patch.object(
         response,
         "json",
-        return_value={"version": 1, "influences": True, "model_class": "image"},
+        return_value={"version": 1, "influences": "grad-cam", "model_class": "image"},
     )
     mocker.patch.object(monitaur._session, "get", return_value=response)
     mocker.patch.object(monitaur, "authenticate", return_value="Token")
@@ -352,25 +421,23 @@ def test_record_transaction_on_image_model_success(mocker):
         "monitaur.client.get_influences",
         return_value=["Glucose <= 99.00", "BMI <= 27.35"],
     )
-
-    mocker.patch.object(os.path, "exists", return_value=True)
-    mocker.patch.object(os.path, "getsize", return_value=7094)
-    mock_open = mocker.patch("builtins.open")
-    mock_open.return_value = BytesIO(b"12345")
-    mocker.patch.object(
-        base64, "b64encode", return_value=b"Image-Base-64-encoded-return-data"
-    )
+    mocker.patch.object(Path, "exists", return_value=True)
+    mock_path_stat = mocker.patch.object(Path, "stat")
+    mock_path_stat.return_value.st_size = 7094
+    mock_upload_file_to_s3 = mocker.patch("monitaur.client.upload_file_to_s3",)
 
     response = requests.Response()
     response.status_code = 200
     mocker.patch.object(response, "json", return_value={"id": 1})
     mocker.patch.object(monitaur._session, "post", return_value=response)
+    mock_add_image = mocker.patch("monitaur.client.add_image",)
 
     transaction_details = monitaur.record_transaction(**image_tran_data)
 
+    assert mock_add_image.call_count == 1
     assert mock_explain_transaction.call_count == 0
     assert transaction_details is not None
-    mock_open.assert_called_once_with("image.png", "rb")
+    assert mock_upload_file_to_s3.call_count == 2
 
 
 def test_record_transaction_raises_client_validation_error_given_bad_request(mocker):
@@ -380,7 +447,9 @@ def test_record_transaction_raises_client_validation_error_given_bad_request(moc
     response = requests.Response()
     response.status_code = 200
     mocker.patch.object(
-        response, "json", return_value={"version": 1, "influences": True}
+        response,
+        "json",
+        return_value={"version": 1, "influences": "anchors", "model_class": "tabular"},
     )
     mocker.patch.object(monitaur._session, "get", return_value=response)
     mocker.patch.object(monitaur, "authenticate", return_value="Token")
@@ -392,11 +461,13 @@ def test_record_transaction_raises_client_validation_error_given_bad_request(moc
     response.status_code = 400
     mocker.patch.object(response, "json", return_value={})
     mocker.patch.object(monitaur._session, "post", return_value=response)
+    mock_upload_file_to_s3 = mocker.patch("monitaur.client.upload_file_to_s3",)
 
     with pytest.raises(ClientValidationError):
         monitaur.record_transaction(**invalid_data)
 
     assert mock_explain_transaction.call_count == 1
+    assert mock_upload_file_to_s3.call_count == 2
 
     monitaur = Monitaur(client_secret="secret")
     response = requests.Response()
@@ -413,25 +484,39 @@ def test_record_training_tabular(trained_model, training_data, mocker):
     monitaur = Monitaur(client_secret="secret")
     response = requests.Response()
     response.status_code = 200
-    mocker.patch.object(response, "json", return_value={"version": 1})
-    mocker.patch.object(monitaur._session, "get", return_value=response)
-    mocker.patch.object(AnchorTabular, "__init__", return_value=None)
-    mocker.patch.object(AnchorTabular, "fit")
+
+    mocker.patch.object(
+        response,
+        "json",
+        return_value={"version": 1, "influences": True, "model_class": "tabular"},
+    )
     mocker.patch.object(monitaur, "authenticate", return_value="Token")
-    boto3_client_mock = mocker.patch.object(boto3, "client")
-    upload_fileobj_mock = boto3_client_mock.return_value.upload_fileobj
+    mocker.patch.object(monitaur._session, "get", return_value=response)
+    mock_open = mocker.patch("builtins.open")
+    mock_open.return_value = BytesIO(b"12345")
+    mocker.patch.object(shutil, "copy", return_value="1.joblib")
+    mocker.patch(
+        "monitaur.client.generate_anchors",
+        return_value=(
+            f"{record_training_data['model_set_id']}.anchors",
+            b"Image-Base-64-encoded-return-data",
+        ),
+    )
+    mock_upload_file_to_s3 = mocker.patch("monitaur.client.upload_file_to_s3",)
+    mock_upload_x_y_train_to_s3 = mocker.patch(
+        "monitaur.client.record_training_file_save",
+    )
 
     result = monitaur.record_training_tabular(
-        trained_model=trained_model, training_data=training_data, **record_training_data
+        trained_model=trained_model,
+        training_data=training_data,
+        **record_training_data,
+        training_outcomes=np.array([3.0, 1.0, 4.0]),
     )
 
     assert result is True
-    assert upload_fileobj_mock.call_count == 2
-
-    filename = f"{record_training_data['model_set_id']}.joblib"
-    filename_anchors = f"{record_training_data['model_set_id']}.anchors"
-    os.remove(filename)
-    os.remove(filename_anchors)
+    assert mock_upload_file_to_s3.call_count == 1
+    assert mock_upload_x_y_train_to_s3.call_count == 1
 
 
 def test_record_training_tabular_with_re_train_true(
@@ -440,14 +525,29 @@ def test_record_training_tabular_with_re_train_true(
     monitaur = Monitaur(client_secret="secret")
     response = requests.Response()
     response.status_code = 200
-    mocker.patch.object(response, "json", return_value={"version": 1})
-    mocker.patch.object(monitaur._session, "get", return_value=response)
-    mocker.patch.object(monitaur._session, "post", return_value=response)
-    mocker.patch.object(AnchorTabular, "__init__", return_value=None)
-    mocker.patch.object(AnchorTabular, "fit")
+
+    mocker.patch.object(
+        response,
+        "json",
+        return_value={"version": 1, "influences": True, "model_class": "tabular"},
+    )
     mocker.patch.object(monitaur, "authenticate", return_value="Token")
-    boto3_client_mock = mocker.patch.object(boto3, "client")
-    upload_fileobj_mock = boto3_client_mock.return_value.upload_fileobj
+    mocker.patch.object(monitaur._session, "get", return_value=response)
+    mock_open = mocker.patch("builtins.open")
+    mock_open.return_value = BytesIO(b"12345")
+    mocker.patch.object(shutil, "copy", return_value="1.joblib")
+    mocker.patch(
+        "monitaur.client.generate_anchors",
+        return_value=(
+            f"{record_training_data['model_set_id']}.anchors",
+            b"Image-Base-64-encoded-return-data",
+        ),
+    )
+    mock_upload_file_to_s3 = mocker.patch("monitaur.client.upload_file_to_s3",)
+    mock_upload_x_y_train_to_s3 = mocker.patch(
+        "monitaur.client.record_training_file_save",
+    )
+
     increase_model_version_mock = mocker.patch.object(
         monitaur, "_increase_model_version"
     )
@@ -456,69 +556,63 @@ def test_record_training_tabular_with_re_train_true(
         trained_model=trained_model,
         training_data=training_data,
         re_train=True,
+        training_outcomes=np.array([3.0, 1.0, 4.0]),
         **record_training_data,
     )
 
     assert result is True
+    assert mock_upload_file_to_s3.call_count == 1
+    assert mock_upload_x_y_train_to_s3.call_count == 1
     increase_model_version_mock.assert_called_with(1, major=True)
-    assert upload_fileobj_mock.call_count == 2
-
-    filename = f"{record_training_data['model_set_id']}.joblib"
-    filename_anchors = f"{record_training_data['model_set_id']}.anchors"
-    os.remove(filename)
-    os.remove(filename_anchors)
 
 
-def test_record_training_image(trained_model, mocker):
+def test_record_training_image(mocker):
     monitaur = Monitaur(client_secret="secret")
     response = requests.Response()
     response.status_code = 200
-    mocker.patch.object(response, "json", return_value={"version": 1})
-    mocker.patch.object(monitaur._session, "get", return_value=response)
 
+    mocker.patch.object(
+        response, "json", return_value={"version": 1, "model_class": "image"}
+    )
+    mocker.patch.object(monitaur._session, "get", return_value=response)
     mocker.patch.object(monitaur, "authenticate", return_value="Token")
-    boto3_client_mock = mocker.patch.object(boto3, "client")
-    upload_fileobj_mock = boto3_client_mock.return_value.upload_fileobj
-    mocker.patch("builtins.open", create=True)
+    mocker.patch.object(shutil, "copy", return_value="1.tar")
+    mock_upload_file_to_s3 = mocker.patch("monitaur.client.upload_file_to_s3",)
+
+    trained_model = Path(DATA_BASE_DIR).joinpath("sample.pth.tar")
 
     result = monitaur.record_training_image(
         trained_model=trained_model, **record_training_image_data
     )
 
     assert result is True
-    assert upload_fileobj_mock.call_count == 1
-
-    filename = f"{record_training_image_data['model_set_id']}.pth.tar"
-    if os.path.exists(filename):
-        os.remove(filename)
+    assert mock_upload_file_to_s3.call_count == 1
 
 
-def test_record_training_image_with_re_train_true(trained_model, mocker):
+def test_record_training_image_with_re_train_true(mocker):
     monitaur = Monitaur(client_secret="secret")
     response = requests.Response()
     response.status_code = 200
-    mocker.patch.object(response, "json", return_value={"version": 1})
+
     mocker.patch.object(monitaur._session, "get", return_value=response)
     mocker.patch.object(monitaur, "authenticate", return_value="Token")
-
-    boto3_client_mock = mocker.patch.object(boto3, "client")
-    mocker.patch("builtins.open", create=True)
-    upload_fileobj_mock = boto3_client_mock.return_value.upload_fileobj
+    mocker.patch.object(
+        response, "json", return_value={"version": 1, "model_class": "image"}
+    )
+    mocker.patch.object(shutil, "copy", return_value="1.tar")
+    mock_upload_file_to_s3 = mocker.patch("monitaur.client.upload_file_to_s3",)
     increase_model_version_mock = mocker.patch.object(
         monitaur, "_increase_model_version"
     )
+    trained_model = Path(DATA_BASE_DIR).joinpath("sample.pth.tar")
 
     result = monitaur.record_training_image(
         trained_model=trained_model, re_train=True, **record_training_image_data,
     )
 
     assert result is True
+    assert mock_upload_file_to_s3.call_count == 1
     increase_model_version_mock.assert_called_with(1, major=True)
-    assert upload_fileobj_mock.call_count == 1
-
-    filename = f"{record_training_image_data['model_set_id']}.pth.tar"
-    if os.path.exists(filename):
-        os.remove(filename)
 
 
 @pytest.mark.parametrize("version, expected_result", [("1.2", 1.3), (2, 2.1)])
@@ -528,56 +622,6 @@ def test_eval(version, expected_result):
     assert monitaur._increase_model_version(version) == expected_result
 
 
-def test_get_credentials_returns_credentials(mocker):
-    monitaur = Monitaur(client_secret="secret")
-    response = requests.Response()
-    response.status_code = 200
-    credentials = {
-        "aws_access_key": "foo",
-        "aws_secret_key": "bar",
-        "aws_region": "us-east-1",
-        "aws_bucket_name": "monitaur-demo",
-    }
-    mocker.patch.object(response, "json", return_value={"credentials": credentials})
-    mocker.patch.object(monitaur._session, "get", return_value=response)
-    mocker.patch.object(monitaur, "authenticate", return_value="Token")
-
-    results = monitaur.get_credentials(1)
-
-    assert results == {
-        "aws_access_key": "foo",
-        "aws_bucket_name": "monitaur-demo",
-        "aws_region": "us-east-1",
-        "aws_secret_key": "bar",
-    }
-
-
-def test_get_credentials_raises_client_auth_error_given_unauthorized_response(mocker,):
-    monitaur = Monitaur(client_secret="secret")
-    response = requests.Response()
-    response.status_code = 401
-    mocker.patch.object(response, "json", return_value={})
-    mocker.patch.object(monitaur._session, "get", return_value=response)
-    mocker.patch.object(monitaur, "authenticate", return_value=response)
-
-    with pytest.raises(ClientAuthError):
-        monitaur.get_credentials(1)
-
-
-def test_get_credentials_raises_client_validation_error_given_bad_request(mocker):
-    monitaur = Monitaur(client_secret="secret")
-    invalid_data = transaction_data.copy()
-    invalid_data["features"] = "invalid features"
-    response = requests.Response()
-    response.status_code = 400
-    mocker.patch.object(response, "json", return_value={})
-    mocker.patch.object(monitaur._session, "get", return_value=response)
-    mocker.patch.object(monitaur, "authenticate", return_value="Token")
-
-    with pytest.raises(ClientValidationError):
-        monitaur.get_credentials("bad")
-
-
 def test_read_transactions_as_unauthorized_client(mocker):
     monitaur = Monitaur(client_secret="secret")
     response = requests.Response()
